Class: Arborist::Event::NodeUpdate

Inherits:
Node show all
Defined in:
lib/arborist/event/node_update.rb

Overview

An event sent on every node update, regardless of whether or not the update resulted in any changes

Instance Attribute Summary

Attributes inherited from Node

#node

Attributes inherited from Arborist::Event

#payload

Method Summary

Methods inherited from Node

#initialize, #match, #payload, #to_h

Methods inherited from Arborist::Event

#initialize, #inspect, #inspect_details, #match, #to_h, #type

Constructor Details

This class inherits a constructor from Arborist::Event::Node