Method: Arborist::Monitor#exec_input

Defined in:
lib/arborist/monitor.rb

#exec_input(&block) ⇒ Object

Declare an input-building callback for the command run by ‘exec’. The block should accept an Array of nodes and a writable IO object, and should write out the necessary input to drive the command to the IO.



400
401
402
403
404
# File 'lib/arborist/monitor.rb', line 400

def exec_input( &block )
	self.exec_callbacks_mod.instance_exec( block ) do |method_body|
		define_method( :exec_input, &method_body )
	end
end